pub struct Node<'i, 'a, Name> {
pub name: Name,
pub content: NodeContent<'i, 'a>,
}Expand description
A single node. Contains the name of the node as well as a NodeContent,
which is used to extract the arguments, properties, and children from
the node.
Fields
name: NameThe name of this node
content: NodeContent<'i, 'a>A processor, used for getting the contents of the node.