RecognizedNode

Type Alias RecognizedNode 

pub type RecognizedNode<'i, 'a> = Node<'i, 'a, ()>;
A recognized node. Used in the case where the caller cares that a node was successfully parsed, but not what the actual value of the node is.

Note that nodes are parsed lazily, so this really only recognizes the node name and annotation.

Aliased Type

pub struct RecognizedNode<'i, 'a> {
    pub name: (),
    pub content: NodeContent<'i, 'a>,
}

Fields

name: ()

The name of this node

content: NodeContent<'i, 'a>

A processor, used for getting the contents of the node.