RecognizedNodeEvent

Type Alias RecognizedNodeEvent 

pub type RecognizedNodeEvent<'i, 'p> = NodeEvent<'i, 'p, (), (), (), (), ()>;
A NodeEvent containing no data. Used when the caller care what kind of thing was in the node, but not the actual value / content.

Aliased Type

pub enum RecognizedNodeEvent<'i, 'p> {
    Argument {
        argument: GenericAnnotated<(), ()>,
        tail: NodeContent<'i, 'p>,
    },
    Property {
        property: GenericProperty<(), (), ()>,
        tail: NodeContent<'i, 'p>,
    },
    Children {
        children: Children<'i, 'p>,
    },
    End,
}

Variants



Argument

An argument from a node

Fields

argument: GenericAnnotated<(), ()>

The value, with its annotation

tail: NodeContent<'i, 'p>

The processor containing the rest of the node



Property

A property (key-value pair) from a node

Fields

property: GenericProperty<(), (), ()>

The property

tail: NodeContent<'i, 'p>

The processor containing the rest of the node



Children

A set of children from the node.

Fields

children: Children<'i, 'p>

A NodeListProcessor used to get child nodes one-by-one



End

There was nothing else in the node.