KdlString

Struct KdlString 

pub struct KdlString<'a> { /* private fields */ }
A KDL string, parsed from an identifier, escaped string, or raw string. Exists in either Owned or Borrowed form, depending on whether there were escapes in the string. Doesn’t track the origin of the string (identifier, escaped, or raw), because KDL semantics treat them all identically.

Implementations

Source

impl<'a> KdlString<'a>

pub fn new() -> Self

Create a new, empty KDL String

pub fn from_cow(cow: Cow<'a, str>) -> Self

Create a KDL string from a Cow<str>.

pub fn from_borrowed(s: &'a str) -> Self

Create a borrowed KDL string

pub fn from_string(s: String) -> Self

Create an owned KDL string

pub fn into_string(self) -> String

Convert this unconditionally into an owned string.

pub fn as_str(&self) -> &str

Get the &str contained in this string.

pub fn visit_to<V, E>(self, visitor: V) -> Result<V::Value, E>
where V: Visitor<'a>, E: Error,

Apply a KDL string to a visitor

Methods from Deref<Target = Cow<'a, str>>

1.0.0 · Source

pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned

Acquires a mutable reference to the owned form of the data.

Clones the data if it is not already owned.

Examples
use std::borrow::Cow;

let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();

assert_eq!(
  cow,
  Cow::Owned(String::from("FOO")) as Cow<'_, str>
);