pub struct KdlString<'a> { /* private fields */ }Expand description
A KDL string, parsed from an identifier, escaped string, or raw string. Exists in either Owned or Borrowed form, depending on whether there were escapes in the string. Doesn’t track the origin of the string (identifier, escaped, or raw), because KDL semantics treat them all identically.
Implementations
Sourceimpl<'a> KdlString<'a>
impl<'a> KdlString<'a>
Sourcepub fn from_borrowed(s: &'a str) -> Self
pub fn from_borrowed(s: &'a str) -> Self
Create a borrowed KDL string
Sourcepub fn from_string(s: String) -> Self
pub fn from_string(s: String) -> Self
Create an owned KDL string
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Convert this unconditionally into an owned string.
Methods from Deref<Target = Cow<'a, str>>
1.0.0 · Sourcepub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
Acquires a mutable reference to the owned form of the data.
Clones the data if it is not already owned.
Examples
use std::borrow::Cow;
let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();
assert_eq!(
cow,
Cow::Owned(String::from("FOO")) as Cow<'_, str>
);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for KdlString<'de>
impl<'de> Deserialize<'de> for KdlString<'de>
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, 'b> Extend<&'b char> for KdlString<'a>
impl<'a, 'b> Extend<&'b char> for KdlString<'a>
Sourcefn extend<T: IntoIterator<Item = &'b char>>(&mut self, iter: T)
fn extend<T: IntoIterator<Item = &'b char>>(&mut self, iter: T)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl<'a> Extend<&'a str> for KdlString<'a>
impl<'a> Extend<&'a str> for KdlString<'a>
Sourcefn extend<T: IntoIterator<Item = &'a str>>(&mut self, iter: T)
fn extend<T: IntoIterator<Item = &'a str>>(&mut self, iter: T)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl Extend<char> for KdlString<'_>
impl Extend<char> for KdlString<'_>
Sourcefn extend<T: IntoIterator<Item = char>>(&mut self, iter: T)
fn extend<T: IntoIterator<Item = char>>(&mut self, iter: T)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl<T> FromIterator<T> for KdlString<'_>where
Self: Extend<T>,
impl<T> FromIterator<T> for KdlString<'_>where
Self: Extend<T>,
Sourcefn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self
fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self
Creates a value from an iterator. Read more
Sourceimpl<'a> StringBuilder<'a> for KdlString<'a>
impl<'a> StringBuilder<'a> for KdlString<'a>
impl<'a> Eq for KdlString<'a>